CHANGELOG
=========

1.1.0(2020-11-15)
-----------------

- Features:
    - Adding support for newer versions of Python and Django
    - Adding support for related paths (Thanks to @hansegucker)

1.0.4(2018-02-19)
-----------------

- Features:
    - Adding support for AppConfig in INSTALLED_APPS

1.0.3(2018-01-31)
-----------------

- Project Enhancements:
    - Dropping support for Python 2
    - Updating docs
    - Readme updating
    - Support for Django 2.0 (Thanks to @lachmanfrantisek)

- Features:
    - Adding support to root paths (Thanks to @lucaskuzma)

- BugFix:
    - Fixing backward compatibility with Django < 1.10

1.0.2(2017-04-29)
-----------------

- Updating .gitignore to ignore sphinx builds
- Updating docs

1.0.1(2017-04-29)
-----------------

- Added docs
- Readme enhanced
- BUGFIX: Added a correction to the validators evaluation with the AND connector
- Added flake8 to CI
- Added tox

1.0.0 (2017-04-09)
------------------

- Initial release
